@@ -4,10 +4,10 @@
 An object-oriented framework for command-line apps.
 """
 
-__version__ = '0.12.0'
+__version__ = '0.13.0'
 
 # Define the public API
-from .app import App, FromParams
+from .app import App, AppMeta
 from .model import init, load, reload
 from .params.param import param, Key
 from .params.toggle import toggle_param, pick_toggled, Toggle as toggle
